@@ -11,16 +11,20 @@
 #include <QObject>
 #include <QString>
 
-#include <KSaneCore>
+#include <Interface>
+#include <DeviceInformation>
 
 #include <memory>
 
 #include "SkanpageUtils.h"
+#include "skanpage_config.h"
+#include "skanpage_state.h"
 
 class DocumentModel;
 class DevicesModel;
 class FormatModel;
 class FilteredOptionsModel;
+class OCRLanguageModel;
 class SkanpagePrivate;
 
 class Skanpage : public QObject
@@ -33,6 +37,9 @@ class Skanpage : public QObject
     Q_PROPERTY(DevicesModel *devicesModel READ devicesModel CONSTANT)
     Q_PROPERTY(FormatModel *formatModel READ formatModel CONSTANT)
     Q_PROPERTY(FilteredOptionsModel *optionsModel READ optionsModel CONSTANT)
+    Q_PROPERTY(OCRLanguageModel *languageModel READ languageModel CONSTANT)
+    Q_PROPERTY(SkanpageConfiguration *configuration READ configuration CONSTANT)
+    Q_PROPERTY(SkanpageState *stateConfiguration READ stateConfiguration CONSTANT)
     Q_PROPERTY(ApplicationState applicationState READ applicationState NOTIFY applicationStateChanged)
 
     Q_PROPERTY(QString deviceVendor READ deviceVendor NOTIFY deviceInfoUpdated)
@@ -66,12 +73,16 @@ public:
     DevicesModel *devicesModel() const;
     FormatModel *formatModel() const;
     FilteredOptionsModel *optionsModel() const;
-    KSaneIface::KSaneCore *ksaneInterface() const;
+    OCRLanguageModel *languageModel() const;
+    KSaneCore::Interface *ksaneInterface() const;
+    SkanpageConfiguration *configuration() const;
+    SkanpageState *stateConfiguration() const;
 
     Q_INVOKABLE void startScan();
     Q_INVOKABLE void cancelScan();
     Q_INVOKABLE void reloadDevicesList();
-    Q_INVOKABLE bool openDevice(const QString &deviceName, const QString &deviceVendor = QString(), const QString &deviceModel = QString());
+    Q_INVOKABLE bool openDevice(const QString &deviceName, const QString &deviceVendor = QString(), const QString &deviceModel = QString());    
+    Q_INVOKABLE bool OCRavailable() const;
 
 Q_SIGNALS:
     void progressChanged(int progress);
@@ -82,13 +93,14 @@ Q_SIGNALS:
     void newUserMessage(const QVariant &level, const QVariant &message);
 
 private Q_SLOTS:
-    void availableDevices(const QList<KSaneIface::KSaneCore::DeviceInfo> &deviceList);
-    void showKSaneMessage(KSaneIface::KSaneCore::KSaneScanStatus type, const QString &strStatus);
-    void showUserMessage(SkanpageUtils::MessageLevel level, const QString &strStatus);
+
     void imageReady(const QImage &image);
+    void availableDevices(const QList<KSaneCore::DeviceInformation *> &deviceList);
+    void showKSaneMessage(KSaneCore::Interface::ScanStatus type, const QString &strStatus);
+    void showUserMessage(SkanpageUtils::MessageLevel level, const QString &strStatus);
     void progressUpdated(int progress);
     void batchModeCountDown(int remainingSeconds);
-    void scanningFinished(KSaneIface::KSaneCore::KSaneScanStatus statuts, const QString &strStatus);
+    void scanningFinished(KSaneCore::Interface::ScanStatus status, const QString &strStatus);
     void imageTemporarilySaved();
 
 private:
